// ResourceActionSource.java
// $Id: ResourceActionSource.java,v 1.3.4.1 1999/10/12 12:04:36 ylafon Exp $
// (c) COPYRIGHT MIT, INRIA and Keio, 1999.
// Please first read the full copyright statement in file COPYRIGHT.html
 
package org.w3c.jigadmin.events;

/**
 * Object that implements this interface cand fire ResourceActionEvent.
 * @version $Revision: 1.3.4.1 $
 * @author  Benot Mah (bmahe@w3.org)
 */
public interface ResourceActionSource {

    /**
     * Add a ResourceActionListener.
     * @param listener the ResourceActionListener to add
     */
    public void addResourceActionListener(ResourceActionListener listener);

    /**
     * Remove a ResourceActionListener.
     * @param listener the ResourceActionListener to remove
     */
    public void removeResourceActionListener(ResourceActionListener listener);

}
